@@ -1,6 +1,7 @@
 import numpy as np
 from xrmreader.reader import read_txrm_iterable, read_metadata
 from scipy.ndimage import shift
+from tqdm import tqdm
 from skimage.measure import block_reduce
 from skimage.transform.pyramids import pyramid_reduce
 
@@ -131,12 +132,12 @@ def read_and_preprocess_txrm(projections_file, downsample_factor=1, angular_fact
                                dtype=datatype)
 
     # todo: can this loop be parallelized without further memory consumption?
-    for i, (projection, x_shift, y_shift) in enumerate(
+    for i, (projection, x_shift, y_shift) in tqdm(enumerate(
             zip(read_txrm_iterable(str(projections_file), slice_range=(
             (0, num_images, angular_factor), (0, metadata['image_height'], 1), (0, metadata['image_width'], 1))),
-                x_shifts, y_shifts)):
-        if i % 10 == 0:
-            print(f'{i + 1} / {int(np.ceil(num_images / angular_factor))}')
+                x_shifts, y_shifts)), total=np.ceil(num_images / angular_factor)):
+        # if i % 10 == 0:
+        #     print(f'{i + 1} / {int(np.ceil(num_images / angular_factor))}')
         projection = np.expand_dims(projection, 0)
         projection = divide_by_reference(projection, reference)
         projection = revert_shifts(projection, x_shift, y_shift)
